<?php
/**
* This file is not included anywhere.  It exists as a way of ensuring some
* strings, which may come from the database, or from other places, are
* present in the translation files.
*
* It is also used to add extra entries to the translations which document
* the sense of a word or phrase to assist with translations.
*/

// Groups, from the database
i18n("Admin <!-- in the sense of 'systems admin' -->");
i18n("Admin");

i18n("Group <!-- in the sense of a group of people -->");
i18n("Group");

i18n("Public <!-- in the sense of being available to all users -->");
i18n("Public");

i18n("Resource <!-- a thing which might be booked: a room, a carpark, a projector... -->");
i18n("Resource");

i18n("No. <!-- short for 'Number' -->");
i18n("No.");

i18n("No <!-- not 'Yes' -->");
i18n("No");
i18n("Yes");

i18n("Id <!-- short for 'Identifier' -->");
i18n("Id");

i18n('View this user record');
i18n('Edit this user record');
i18n('You are viewing');
i18n('You are editing');

i18n("forget me not <!-- this is a colloquial phrase in english (the name of a flower) and is an option allowing people to log in automatically in future -->");

// Date format types
i18n('European');
i18n('US Format');
i18n('ISO Format');

// Calendar schedule transparency
i18n('Opaque');
i18n('Transparent');

// Unspecified timezone value
i18n('*** Unknown ***');

i18n('Person');
